@@ -567,9 +567,9 @@ NumericVector fdiffgrowthCppImpl(const NumericVector& x, const IntegerVector& n
       CharacterVector classes = Rf_getAttrib(out, R_ClassSymbol);
       classes.push_back("matrix");
       Rf_classgets(out, classes);
-    } else {
-      Rf_classgets(out, Rf_mkString("matrix"));
-    }
+    } // else {
+      // Rf_classgets(out, Rf_mkString("matrix"));
+      // }
     if(names) Rf_dimnamesgets(out, List::create(Rf_getAttrib(x, R_NamesSymbol), colnam));
   }
 
